@@ -29,7 +29,7 @@ fn load_bat_themes() -> Result<ThemeSet> {
 }
 
 fn load_syntax_set() -> Result<SyntaxSet> {
-    Ok(bincode::deserialize_from(ZlibDecoder::new(SYNTAX_SET_BIN))?)
+    Ok(bincode::deserialize_from(SYNTAX_SET_BIN)?)
 }
 
 pub trait LockableWrite<'a> {
@@ -54,7 +54,7 @@ fn list_themes_with_syntaxes<W: Write>(
     opts: &PrinterOptions<'_>,
     syntaxes: &SyntaxSet,
 ) -> Result<()> {
-    use crate::io::IgnoreBrokenPipe;
+    use crate::broken_pipe::IgnoreBrokenPipe;
 
     let themes = {
         let mut m = load_bat_themes()?.themes;
@@ -69,7 +69,7 @@ fn list_themes_with_syntaxes<W: Write>(
 
     themes
         .iter()
-        .try_for_each(|(name, theme)| {
+        .try_for_each(|(name, theme)| -> Result<()> {
             let mut drawer = Drawer::new(&mut out, opts, theme, &sample_file.chunks);
             drawer.canvas.set_bold()?;
             write!(drawer.canvas, "{:?}", name)?;
@@ -79,7 +79,7 @@ fn list_themes_with_syntaxes<W: Write>(
 
             let hl = LineHighlighter::new(syntax, theme, syntaxes);
             drawer.draw_file(&sample_file, hl)?;
-            writeln!(drawer.canvas)
+            Ok(writeln!(drawer.canvas)?)
         })
         .ignore_broken_pipe()?;
 
@@ -624,19 +624,21 @@ impl<'a> LineHighlighter<'a> {
         }
     }
 
-    fn skip_line(&mut self, line: &str) {
-        let ops = self.parse_state.parse_line(line, self.syntaxes);
+    fn skip_line(&mut self, line: &str) -> Result<()> {
+        let ops = self.parse_state.parse_line(line, self.syntaxes)?;
         for _ in HighlightIterator::new(&mut self.hl_state, &ops, line, &self.hl) {}
+        Ok(())
     }
 
-    fn highlight<'line>(&mut self, line: &'line str) -> Vec<Token<'line>> {
-        let ops = self.parse_state.parse_line(line, self.syntaxes);
-        HighlightIterator::new(&mut self.hl_state, &ops, line, &self.hl)
+    fn highlight<'line>(&mut self, line: &'line str) -> Result<Vec<Token<'line>>> {
+        let ops = self.parse_state.parse_line(line, self.syntaxes)?;
+        let tokens = HighlightIterator::new(&mut self.hl_state, &ops, line, &self.hl)
             .map(|(mut style, text)| {
                 style.foreground = blend_fg_color(style.foreground, style.background);
                 Token { style, text }
             })
-            .collect()
+            .collect();
+        Ok(tokens)
     }
 }
 
@@ -903,7 +905,7 @@ impl<'file, W: Write> Drawer<'file, W> {
         self.canvas.draw_newline()
     }
 
-    fn draw_body(&mut self, file: &File, mut hl: LineHighlighter<'_>) -> io::Result<()> {
+    fn draw_body(&mut self, file: &File, mut hl: LineHighlighter<'_>) -> Result<()> {
         assert!(!file.chunks.is_empty());
 
         let mut matched = file.line_matches.as_ref();
@@ -913,7 +915,7 @@ impl<'file, W: Write> Drawer<'file, W> {
         for Line(bytes, lnum) in LinesInclusive::new(&file.contents) {
             let (start, end) = *chunk;
             if lnum < start {
-                hl.skip_line(String::from_utf8_lossy(bytes).as_ref()); // Discard parsed result
+                hl.skip_line(String::from_utf8_lossy(bytes).as_ref())?; // Discard parsed result
                 continue;
             }
             if start <= lnum && lnum <= end {
@@ -927,7 +929,7 @@ impl<'file, W: Write> Drawer<'file, W> {
                 let line = String::from_utf8_lossy(bytes);
                 // Collect to `Vec` rather than handing HighlightIterator as-is. HighlightIterator takes ownership of Highlighter
                 // while the iteration. When the highlighter is stored in `self`, it means the iterator takes ownership of `self`.
-                self.draw_line(hl.highlight(line.as_ref()), lnum, regions)?;
+                self.draw_line(hl.highlight(line.as_ref())?, lnum, regions)?;
 
                 if lnum == end {
                     if self.first_only {
@@ -971,10 +973,11 @@ impl<'file, W: Write> Drawer<'file, W> {
         Ok(())
     }
 
-    fn draw_file(&mut self, file: &File, hl: LineHighlighter) -> io::Result<()> {
+    fn draw_file(&mut self, file: &File, hl: LineHighlighter) -> Result<()> {
         self.draw_header(&file.path)?;
         self.draw_body(file, hl)?;
-        self.draw_footer()
+        self.draw_footer()?;
+        Ok(())
     }
 }
 
@@ -1068,23 +1071,79 @@ where
             if self.opts.color_support == TermColorSupport::Ansi16 {
                 "ansi"
             } else {
-                "Monokai Extended" // Our 25bit -> 8bit color conversion works really well with this colorscheme
+                "Monokai Extended" // 25bit -> 8bit color conversion works really well with this colorscheme
             }
         });
         &self.themes.themes[name]
     }
 
     fn find_syntax(&self, path: &Path) -> Result<&SyntaxReference> {
+        // Find from file extension
         let name = match path.extension().and_then(OsStr::to_str) {
             Some("fs") => Some("F#"),
             Some("h") => Some("C++"),
             Some("pac") => Some("JavaScript (Babel)"),
+            Some("nse") => Some("Lua"),
+            Some(
+                "automount" | "device" | "dnssd" | "link" | "mount" | "netdev" | "network"
+                | "nspawn" | "path" | "service" | "scope" | "slice" | "socket" | "swap" | "target"
+                | "timer",
+            ) => Some("INI"),
             _ => None,
         };
+
+        // Find from file name
         let name = name.or_else(|| match path.file_name().and_then(OsStr::to_str) {
-            Some(".clang-format") => Some("YAML"),
+            Some(".clang-format" | "fish_history") => Some("YAML"),
+            Some("nginx.conf" | "mime.types") => Some("nginx"),
+            Some("httpd.conf") => Some("Apache Conf"),
             _ => None,
         });
+
+        // Find from file path
+        let name = name.or_else(|| {
+            #[cfg(not(windows))]
+            const GIT_CONFIG: &str = "/git/config";
+            #[cfg(windows)]
+            const GIT_CONFIG: &str = "\\git\\config";
+            #[cfg(not(windows))]
+            const GIT_IGNORE: &str = "/git/ignore";
+            #[cfg(windows)]
+            const GIT_IGNORE: &str = "\\git\\ignore";
+            #[cfg(not(windows))]
+            const GIT_ATTRIBUTES: &str = "/git/attributes";
+            #[cfg(windows)]
+            const GIT_ATTRIBUTES: &str = "\\git\\attributes";
+            #[cfg(not(windows))]
+            const SSH_CONFIG: &str = "/.ssh/config";
+            #[cfg(windows)]
+            const SSH_CONFIG: &str = "\\.ssh\\config";
+
+            let path = path.to_str()?;
+            if path.ends_with(GIT_CONFIG) {
+                return Some("Git Config");
+            }
+            if path.ends_with(GIT_IGNORE) {
+                return Some("Git Ignore");
+            }
+            if path.ends_with(GIT_ATTRIBUTES) {
+                return Some("Git Attributes");
+            }
+            if path.ends_with(SSH_CONFIG) {
+                return Some("SSH Config");
+            }
+            #[cfg(not(windows))]
+            if path == "/etc/profile" {
+                return Some("Bourne Again Shell (bash)");
+            }
+            #[cfg(not(windows))]
+            if path.starts_with("/var/spool/mail/") || path.starts_with("/var/mail/") {
+                return Some("Email");
+            }
+
+            None
+        });
+
         if let Some(syntax) = name.and_then(|n| self.syntaxes.find_syntax_by_name(n)) {
             return Ok(syntax);
         }
@@ -1101,7 +1160,7 @@ where
     for<'a> W: LockableWrite<'a>,
 {
     fn print(&self, file: File) -> Result<()> {
-        use crate::io::IgnoreBrokenPipe;
+        use crate::broken_pipe::IgnoreBrokenPipe;
 
         if file.chunks.is_empty() || file.line_matches.is_empty() {
             return Ok(());
